import { IUser } from "@aws-cdk/aws-iam";
import { ISecret } from "@aws-cdk/aws-secretsmanager";
import { Construct } from "@aws-cdk/core";
/**
 * @stability stable
 */
export interface SesSmtpCredentialsProps {
    /**
     * The user for which to create an AWS Access Key and to generate the smtp password.
     *
     * @stability stable
     */
    readonly user: IUser;
    /**
     * Optional, an SecretsManager secret to write the AWS SES Smtp credentials to.
     *
     * @stability stable
     */
    readonly secret?: ISecret;
}
/**
 * This construct creates an access key for the given user and stores the generated SMTP credentials inside a secret.
 *
 * @stability stable
 * @example
 *
 * const user = User.fromUserName("ses-user-example");
 * const credentials = new SesSmtpCredentials(this, 'SmtpCredentials', {
 *     user: user,
 * });
 * // credentials.secret
 */
export declare class SesSmtpCredentials extends Construct {
    /**
     * @stability stable
     */
    readonly secret: ISecret;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: SesSmtpCredentialsProps);
}
